/**
 * Marks GLSL shaders for syntax highlighting: glsl`...`
 * Install https://marketplace.visualstudio.com/items?itemName=boyswan.glsl-literal
 */
export { glsl } from "./lib/glsl-utils/highlight.js";
export type { PlatformInfo } from "./lib/shader-assembly/platform-info.js";
export type { ShaderModule } from "./lib/shader-module/shader-module.js";
export type { ShaderPass } from "./lib/shader-module/shader-pass.js";
export type { ShaderHook } from "./lib/shader-assembly/shader-hooks.js";
export type { ShaderInjection } from "./lib/shader-assembly/shader-injections.js";
export { ShaderModuleInstance } from "./lib/shader-module/shader-module-instance.js";
export { ShaderAssembler } from "./lib/shader-assembler.js";
export { normalizeShaderModule } from "./lib/shader-module/normalize-shader-module.js";
export { getShaderInfo } from "./lib/glsl-utils/get-shader-info.js";
export { getQualifierDetails, getPassthroughFS, typeToChannelSuffix, typeToChannelCount, convertToVec4 } from "./lib/glsl-utils/shader-utils.js";
export type { ShaderGenerationOptions } from "./lib/shader-generator/generate-shader.js";
export { generateShaderForModule } from "./lib/shader-generator/generate-shader.js";
export { capitalize } from "./lib/shader-generator/utils/capitalize.js";
export { assembleShaderPairGLSL } from "./lib/shader-assembly/assemble-shaders.js";
export { ShaderModuleInstance as _ShaderModuleInstance } from "./lib/shader-module/shader-module-instance.js";
export { combineInjects } from "./lib/shader-assembly/shader-injections.js";
export { resolveModules as _resolveModules } from "./lib/shader-assembly/resolve-modules.js";
export { getDependencyGraph as _getDependencyGraph } from "./lib/shader-assembly/resolve-modules.js";
export { getShaderLayoutFromWGSL } from "./lib/wgsl/get-shader-layout-wgsl.js";
export { random } from "./modules/math/random/random.js";
export { fp32 } from "./modules/math/fp32/fp32.js";
export type { PickingProps } from "./modules/engine/picking/picking.js";
export { picking } from "./modules/engine/picking/picking.js";
export type { LightingProps } from "./modules/lighting/lights/lighting-uniforms.js";
export { lighting } from "./modules/lighting/lights/lighting-uniforms.js";
export { dirlight } from "./modules/lighting/no-material/dirlight.js";
export type { GouraudMaterialProps } from "./modules/lighting/gouraud-material/gouraud-material.js";
export { gouraudMaterial } from "./modules/lighting/gouraud-material/gouraud-material.js";
export type { PhongMaterialProps } from "./modules/lighting/phong-material/phong-material.js";
export { phongMaterial } from "./modules/lighting/phong-material/phong-material.js";
export { pbrMaterial } from "./modules/lighting/pbr-material/pbr-material.js";
export type { BrightnessContrastProps } from "./modules/postprocessing/image-adjust-filters/brightnesscontrast.js";
export { brightnessContrast } from "./modules/postprocessing/image-adjust-filters/brightnesscontrast.js";
export type { DenoiseProps } from "./modules/postprocessing/image-adjust-filters/denoise.js";
export { denoise } from "./modules/postprocessing/image-adjust-filters/denoise.js";
export type { HueSaturationProps } from "./modules/postprocessing/image-adjust-filters/huesaturation.js";
export { hueSaturation } from "./modules/postprocessing/image-adjust-filters/huesaturation.js";
export type { NoiseProps } from "./modules/postprocessing/image-adjust-filters/noise.js";
export { noise } from "./modules/postprocessing/image-adjust-filters/noise.js";
export type { SepiaProps } from "./modules/postprocessing/image-adjust-filters/sepia.js";
export { sepia } from "./modules/postprocessing/image-adjust-filters/sepia.js";
export type { VibranceProps } from "./modules/postprocessing/image-adjust-filters/vibrance.js";
export { vibrance } from "./modules/postprocessing/image-adjust-filters/vibrance.js";
export type { VignetteProps } from "./modules/postprocessing/image-adjust-filters/vignette.js";
export { vignette } from "./modules/postprocessing/image-adjust-filters/vignette.js";
export type { TiltShiftProps } from "./modules/postprocessing/image-blur-filters/tiltshift.js";
export { tiltShift } from "./modules/postprocessing/image-blur-filters/tiltshift.js";
export type { TriangleBlurProps } from "./modules/postprocessing/image-blur-filters/triangleblur.js";
export { triangleBlur } from "./modules/postprocessing/image-blur-filters/triangleblur.js";
export type { ZoomBlurProps } from "./modules/postprocessing/image-blur-filters/zoomblur.js";
export { zoomBlur } from "./modules/postprocessing/image-blur-filters/zoomblur.js";
export type { ColorHalftoneProps } from "./modules/postprocessing/image-fun-filters/colorhalftone.js";
export { colorHalftone } from "./modules/postprocessing/image-fun-filters/colorhalftone.js";
export type { DotScreenProps } from "./modules/postprocessing/image-fun-filters/dotscreen.js";
export { dotScreen } from "./modules/postprocessing/image-fun-filters/dotscreen.js";
export type { EdgeWorkProps } from "./modules/postprocessing/image-fun-filters/edgework.js";
export { edgeWork } from "./modules/postprocessing/image-fun-filters/edgework.js";
export type { HexagonalPixelateProps } from "./modules/postprocessing/image-fun-filters/hexagonalpixelate.js";
export { hexagonalPixelate } from "./modules/postprocessing/image-fun-filters/hexagonalpixelate.js";
export type { InkProps } from "./modules/postprocessing/image-fun-filters/ink.js";
export { ink } from "./modules/postprocessing/image-fun-filters/ink.js";
export type { MagnifyProps } from "./modules/postprocessing/image-fun-filters/magnify.js";
export { magnify } from "./modules/postprocessing/image-fun-filters/magnify.js";
export type { BulgePinchProps } from "./modules/postprocessing/image-warp-filters/bulgepinch.js";
export { bulgePinch } from "./modules/postprocessing/image-warp-filters/bulgepinch.js";
export type { SwirlProps } from "./modules/postprocessing/image-warp-filters/swirl.js";
export { swirl } from "./modules/postprocessing/image-warp-filters/swirl.js";
export { fxaa } from "./modules/postprocessing/fxaa/fxaa.js";
export type { WarpProps } from "./modules/postprocessing/image-warp-filters/warp.js";
export { warp as _warp } from "./modules/postprocessing/image-warp-filters/warp.js";
export { fp64, fp64arithmetic } from "./modules-webgl1/math/fp64/fp64.js";
export { geometry as geometry1 } from "./modules-webgl1/geometry/geometry.js";
export { project as project1 } from "./modules-webgl1/project/project.js";
export { lights as lights1 } from "./modules-webgl1/lighting/lights/lights.js";
export { dirlight as dirlight1 } from "./modules-webgl1/lighting/dirlight/dirlight.js";
export { gouraudLighting, phongLighting } from "./modules-webgl1/lighting/phong-lighting/phong-lighting.js";
export { pbr } from "./modules-webgl1/lighting/pbr/pbr.js";
//# sourceMappingURL=index.d.ts.map